const express = require('express');
const router  = express.Router();
const {nanoid} = require('fix-esm').require('nanoid');
const multer = require('multer');
const path = require('path');
const {uploadPath} = require('./../config');
const Product = require('../models/Product');

const storage = multer.diskStorage({
   destination: (req, file, cb) => {
       cb(null, uploadPath);
   },
    filename: (req, file, cb) => {
       cb(null, nanoid() + path.extname(file.originalname));
    }
});

const upload = multer({storage});

const createRoutes = () => {
    router.post('/', upload.single('image'), async (req, res) => {
        const productData = {...req.body};

        if (req.file) productData.image = req.file.filename;
        else productData.image = null;

        try {
            const product = new Product(productData);

            res
                .status(201)
                .send(await product.save());
        } catch (e) {
            res
                .status(400)
                .send(e);
        }
    });

    router.get('/', async (req, res) => {
        try {
            res.send(await Product.find());
        } catch (e) {
            res.sendStatus(500);
        }
    });

    router.get('/:id', async (req, res) => {
        try {
            const result = await Product.findById(req.params.id);

            if (result) return res.send(result);

            res.sendStatus(404);
        } catch (e) {
            res.sendStatus(500);
        }
    });

    return router;
};

module.exports = createRoutes;
